@@ -21,6 +21,20 @@ class AlbumResult(object):
 	def empty(self):
 		return (not self.imgs) and (not self.cap) and (not self.video)
 
+	def __str__(self):
+		return '\t'.join([k + ':' + str(v) for (k,v) in self.__dict__.items() if v])
+
+def cleanUrl(text):
+	for special_char in ['https://', 'http://']:
+		text = text.replace(special_char, '')
+	text = text.replace('  ', ' ')
+	for _ in range(10):
+		text = text.replace('\n ', '\n')
+		text = text.replace(' \n', '\n')
+	for _ in range(10):	
+		text = text.replace('\n\n\n', '\n\n')
+	return text.strip()
+
 def escapeMarkdown(text):
 	in_bracket = False
 	r = []
@@ -33,24 +47,14 @@ def escapeMarkdown(text):
 			r.append("\\")
 		r.append(x)
 	text = ''.join(r)
-	for special_char in ['`', '*', 'https://', 'http://']:
+	for special_char in ['`', '*']:
 		text = text.replace(special_char, '')
-	text = text.replace('  ', ' ')
-	text = text.replace('\n ', '\n')
-	return text
-
-def clearUrl(url):
-	url = url.split('#')[0]
-	if 'weibo' in url and 'id=' not in url: 
-		url = url.split('?')[0]
-	if url.endswith('/'):
-		url = url[:-1]
-	return url
+	return cleanUrl(text)
 
 def getWid(url):
 	url = clearUrl(url)
 	if 'id=' in url:
-		return url[url.find('id=') + 3:]
+		return url[url.find('id=') + 3:].split('&')[0]
 	return url.split('/')[-1]
 		
 def cutCaption(quote, suffix, limit):
@@ -106,8 +110,11 @@ def getDisplayChat(chat):
 		return chat.title
 
 def formatChat(bot, chat_id):
-	chat = bot.getChat(chat_id)
-	return getDisplayChat(chat)
+	try:
+		chat = bot.getChat(chat_id)
+		return getDisplayChat(chat)
+	except:
+		return str(chat_id)
 
 def log_on_fail(debug_group = None, error_to_ignore=[]):
 	def decorate(f):
@@ -143,10 +150,10 @@ def splitCommand(text):
 	command = pieces[0]
 	return command.lower(), text[text.find(command) + len(command):].strip()
 
-def tryDelete(msg):
-	try:
-		msg.delete()
-	except:
+def tryDelete(msg):	
+	try:	
+		msg.delete()	
+	except:	
 		pass
 
 def autoDestroy(msg, minutes=1):
@@ -233,4 +240,16 @@ def getLinkFromMsg(msg):
 			url = msg.text[item["offset"]:][:item["length"]]
 			if not '://' in url:
 				url = "https://" + url
-			return url
\ No newline at end of file
+			return url
+
+def clearUrl(url):
+	for end_char in ['/?utm_source']:
+		url = url.split(end_char)[0]
+	for end_char in ['#']:
+		if 'id=' not in url:
+			url = url.split(end_char)[0]
+	if matchKey(url, ['weibo', 'thepaper', 'm.sohu']) and 'id=' not in url: 
+		url = url.split('?')[0]
+	if url.endswith('/'):
+		url = url[:-1]
+	return url
\ No newline at end of file
